@@ -1,5 +1,14 @@
+"""
+Parsing errors
+--------------
+Here you find all the errors that may be thrown during the parsing process.
+"""
+
+
 class ModuleDeclarationMissingException(Exception):
+    """ Error thrown when the module declaration is absent """
     def __init__(self, filename):
+        """Initializes the Exception, with the filename so that the error message is more helpful."""
         self.message = """\
 -- EMPTY MODULE --------------------------------------------- {0}
 
@@ -17,4 +26,4 @@ I am looking for one of the following things:
         super().__init__(self.message)
 
     def __call__(self, *args, **kwargs):
-        raise self
\ No newline at end of file
+        raise self
